import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["size", "type", "openLightBox", "renderLightBox", "videoTitle", "formatCTAcopy"];
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
/**
 * Copyright IBM Corp. 2016, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
import CTALogic from './CTALogic';
import { FeatureCard } from '../FeatureCard';
import PropTypes from 'prop-types';
import React from 'react';

/**
 * FeatureCard subcomponent for CTA.
 */
var FeatureCTA = function FeatureCTA(_ref) {
  var size = _ref.size,
    type = _ref.type,
    openLightBox = _ref.openLightBox,
    renderLightBox = _ref.renderLightBox,
    videoTitle = _ref.videoTitle,
    formatCTAcopy = _ref.formatCTAcopy,
    otherProps = _objectWithoutProperties(_ref, _excluded);
  return type === 'video' ? /*#__PURE__*/React.createElement("div", null, CTALogic.launchLightBox(renderLightBox, openLightBox, otherProps.card.cta.media), !renderLightBox && /*#__PURE__*/React.createElement(FeatureCard, {
    card: _renderFeatureCard({
      card: _objectSpread(_objectSpread({}, otherProps.card), {}, {
        heading: formatCTAcopy({
          title: videoTitle[0].title,
          duration: videoTitle[0].duration
        })
      })
    }),
    size: size,
    onClick: function onClick(e) {
      return CTALogic.setLightBox(e, openLightBox);
    }
  })) : /*#__PURE__*/React.createElement(FeatureCard, {
    card: _renderFeatureCard({
      card: _objectSpread({}, otherProps.card)
    }),
    size: size
  });
};

/**
 * sets featureCard
 *
 * @param {object} param param object
 * @param {object} param.card card object
 * @private
 * @returns {*} object
 */
var _renderFeatureCard = function _renderFeatureCard(_ref2) {
  var card = _ref2.card;
  if (card.type === 'jump') card.cta.type = 'jump';else if (card.type === 'video') card.cta.href = '#';
  card.cta = _objectSpread(_objectSpread({}, card.cta), {}, {
    icon: {
      src: CTALogic.iconSelector(card.cta.type)
    }
  });
  card.type = 'link';
  return card;
};
FeatureCTA.propTypes = {
  /**
   * Size of Feature Card. Choose from:
   *
   * | Name    | Description                                                  |
   * | ------- | -------------------------------------------------------------|
   * | `medium`| Default Feature Card variant                                 |
   * | `large` | Large Feature Card variant that contains eyebrow and heading |
   */
  size: PropTypes.oneOf(['medium', 'large']),
  /**
   * CTA type. Choose from:
   *
   * | Type       | SVG element Name | Description                                                      |
   * | ---------- | ---------------- | ---------------------------------------------------------------- |
   * | `local`    | ArrowRight20     | Describes right arrow onClick which loads in self page.          |
   * | `jump`     | ArrowDown20      | Describes down arrow onClick which scrollToView of target.       |
   * | `external` | Launch20         | Describes launch arrow onClick which loads in new tab.           |
   * | `download` | Download20       | Describes download arrow onClick for downloading files.          |
   * | `video`    | PlayOutline20    | Describes play icon onClick which loads the video in a lightbox. |
   * | `default`  | None             | Describes the default CTA - without icon                         |
   *
   * For more details of icons, refer to:
   *
   * - [Icons library](https://www.carbondesignsystem.com/guidelines/icons/library/)!👀
   * - [@carbon/icons-react](https://github.com/carbon-design-system/carbon/tree/v1/packages/icons-react)!👀
   * - [carbon-icons](https://www.npmjs.com/package/carbon-icons)!👀
   */
  type: PropTypes.oneOfType([PropTypes.oneOf(['jump', 'local', 'external', 'download', 'video', 'default']), PropTypes.arrayOf(PropTypes.oneOf(['jump', 'local', 'external', 'download', 'video', 'default']))]),
  /**
   * Func to set renderLightBox state.
   */
  openLightBox: PropTypes.func,
  /**
   * Bool to determine whether to open lightbox.
   */
  renderLightBox: PropTypes.bool,
  /**
   * Array of video titles.
   */
  videoTitle: PropTypes.arrayOf(PropTypes.shape({
    title: PropTypes.string,
    duration: PropTypes.string,
    key: PropTypes.oneOfType([PropTypes.number, PropTypes.string])
  })),
  /**
   * Func to format the cta copy
   */
  formatCTAcopy: PropTypes.func
};
FeatureCTA.defaultProps = {
  type: 'default',
  formatCTAcopy: function formatCTAcopy(_ref3) {
    var title = _ref3.title,
      duration = _ref3.duration;
    return "".concat(title, " ").concat(duration);
  }
};
export default FeatureCTA;