import _extends from "@babel/runtime/helpers/extends";
/**
 * Copyright IBM Corp. 2016, 2022
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import classNames from 'classnames';
import ContentGroup from '../ContentGroup/ContentGroup';
import ddsSettings from '../../internal/vendor/@carbon/ibmdotcom-utilities/utilities/settings/settings';
import { PictogramItem } from '../PictogramItem';
import PropTypes from 'prop-types';
import React from 'react';
import settings from 'carbon-components/es/globals/js/settings';
var stablePrefix = ddsSettings.stablePrefix;
var prefix = settings.prefix;

/**
 * Content group — with pictograms.
 */
var ContentGroupPictograms = function ContentGroupPictograms(_ref) {
  var heading = _ref.heading,
    items = _ref.items,
    className = _ref.className,
    copy = _ref.copy;
  return /*#__PURE__*/React.createElement("div", {
    "data-autoid": "".concat(stablePrefix, "--content-group-pictograms"),
    className: classNames(className, "".concat(prefix, "--content-group-pictograms"))
  }, /*#__PURE__*/React.createElement(ContentGroup, {
    heading: heading,
    copy: copy
  }, _renderItems(items)));
};

/**
 * Renders the array of items
 *
 * @param {Array} items Array of items for PictogramItem
 * @returns {*} PictogramItem JSX components
 */
var _renderItems = function _renderItems(items) {
  return items.map(function (item, index) {
    return /*#__PURE__*/React.createElement(PictogramItem, _extends({
      className: "".concat(prefix, "--content-group-pictograms__item"),
      "data-autoid": "".concat(prefix, "--content-group-pictograms__item")
    }, item, {
      key: index
    }));
  });
};
ContentGroupPictograms.propTypes = {
  /**
   * Main title of Content Group — with Pictograms pattern.
   */
  heading: PropTypes.string.isRequired,
  /**
   * Copy text (enabled for the `markdownToHtml` utility)
   */
  copy: PropTypes.string,
  /**
   * Array of PictogramItems.
   * See [`<PictogramItem>`'s README](http://www.ibm.com/standards/carbon/react/?path=/docs/components-pictogramitem--default#props) for full usage details.
   */
  items: PropTypes.arrayOf(PropTypes.shape({
    heading: PropTypes.string.isRequired,
    copy: PropTypes.string.isRequired,
    cta: PropTypes.shape({
      style: PropTypes.oneOf(['text', 'card', 'button', 'feature']),
      type: PropTypes.oneOfType([PropTypes.oneOf(['jump', 'local', 'external', 'download', 'video']), PropTypes.arrayOf(PropTypes.oneOf(['jump', 'local', 'external', 'download', 'video']))]),
      copy: PropTypes.string,
      href: PropTypes.string,
      customClassName: PropTypes.string
    }),
    pictogram: PropTypes.shape({
      src: PropTypes.object.isRequired
    }),
    className: PropTypes.string
  })).isRequired,
  /**
   * The CSS class name to apply to the top-level element.
   */
  className: PropTypes.string
};
export default ContentGroupPictograms;