import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
/**
 * Copyright IBM Corp. 2020, 2022
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import React, { useState, useRef } from 'react';
import Button from '../../internal/vendor/carbon-components-react/components/Button/Button';
import ddsSettings from '../../internal/vendor/@carbon/ibmdotcom-utilities/utilities/settings/settings';
import EarthFilled20 from '@carbon/icons-react/es/earth--filled/20';
import LocaleModal from '../LocaleModal/LocaleModal';
import PropTypes from 'prop-types';
import settings from 'carbon-components/es/globals/js/settings';
var stablePrefix = ddsSettings.stablePrefix;
var prefix = settings.prefix;

/**
 * Renders the locale button.
 */
var LocaleButton = function LocaleButton(_ref) {
  var displayLang = _ref.displayLang,
    aria = _ref.aria;
  var _useState = useState(false),
    _useState2 = _slicedToArray(_useState, 2),
    isOpen = _useState2[0],
    setIsOpen = _useState2[1];
  var localeButton = useRef();
  return /*#__PURE__*/React.createElement("div", {
    className: "".concat(prefix, "--locale-btn__container")
  }, /*#__PURE__*/React.createElement(Button, {
    "data-autoid": "".concat(stablePrefix, "--locale-btn"),
    className: "".concat(prefix, "--locale-btn"),
    kind: "tertiary",
    ref: localeButton,
    onClick: open,
    renderIcon: EarthFilled20,
    iconDescription: "Earth Filled Icon",
    "aria-label": aria
  }, displayLang), /*#__PURE__*/React.createElement(LocaleModal, {
    isOpen: isOpen,
    setIsOpen: setIsOpen,
    closeFunc: function closeFunc() {
      setTimeout(function () {
        localeButton.current.focus();
      });
    }
  }));

  /**
   * Sets modal state to open
   *
   * @private
   */
  function open() {
    setIsOpen(true);
  }
};
LocaleButton.propTypes = {
  /**
   * Display language for locale button.
   */
  displayLang: PropTypes.string,
  /**
   * `aria-label`` value.
   */
  aria: PropTypes.string
};
export default LocaleButton;