import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["backButtonText", "navigation", "isSideNavExpanded", "platform"];
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
/**
 * Copyright IBM Corp. 2016, 2022
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
import React, { useEffect, useRef, useState } from 'react';
import cx from 'classnames';
import ddsSettings from '../../internal/vendor/@carbon/ibmdotcom-utilities/utilities/settings/settings';
import HeaderSideNavItems from '../../internal/vendor/carbon-components-react/components/UIShell/HeaderSideNavItems';
import PropTypes from 'prop-types';
import root from 'window-or-global';
import settings from 'carbon-components/es/globals/js/settings';
import SideNav from '../../internal/vendor/carbon-components-react/components/UIShell/SideNav';
import SideNavItems from '../../internal/vendor/carbon-components-react/components/UIShell/SideNavItems';
import SideNavMenu from '../carbon-components-react/UIShell/SideNavMenu';
import SideNavMenuItem from '../../internal/vendor/carbon-components-react/components/UIShell/SideNavMenuItem';
import SideNavMenuSection from '../carbon-components-react/UIShell/SideNavMenuSection';
var stablePrefix = ddsSettings.stablePrefix;
var prefix = settings.prefix;

/**
 * Masthead left nav component.
 */
var MastheadLeftNav = function MastheadLeftNav(_ref) {
  var backButtonText = _ref.backButtonText,
    navigation = _ref.navigation,
    isSideNavExpanded = _ref.isSideNavExpanded,
    platform = _ref.platform,
    rest = _objectWithoutProperties(_ref, _excluded);
  /**
   * checks if menu item's children url match the current url path, if so return the menu item and its children
   * will set the selected state for entire hierarchy of menu items
   *
   * @returns {object} selectedItems
   */
  // eslint-disable-next-line class-methods-use-this
  var _selectedLeftNavItems = function _selectedLeftNavItems() {
    var matchFound = false;
    var selectedItems = {
      level0: '',
      level1: '',
      level2: ''
    };
    return function (_ref2) {
      var _root$location;
      var _ref2$menu = _ref2.menu,
        menu = _ref2$menu === void 0 ? [{
          url: '',
          megapanelContent: {
            quickLinks: {
              links: [{
                url: ''
              }]
            }
          }
        }] : _ref2$menu,
        _ref2$key = _ref2.key,
        key = _ref2$key === void 0 ? '' : _ref2$key,
        _ref2$parentItemUrl = _ref2.parentItemUrl,
        parentItemUrl = _ref2$parentItemUrl === void 0 ? '' : _ref2$parentItemUrl;
      var currentUrlPath = (_root$location = root.location) === null || _root$location === void 0 ? void 0 : _root$location.href;
      if (!matchFound) {
        if (parentItemUrl === currentUrlPath) {
          selectedItems.level0 = "".concat(key);
          matchFound = true;
        }
        // check if child url matches current url path
        else {
          for (var i = 0; i < (menu === null || menu === void 0 ? void 0 : menu.length); i++) {
            var _menu$i;
            if (((_menu$i = menu[i]) === null || _menu$i === void 0 ? void 0 : _menu$i.url) === currentUrlPath) {
              selectedItems.level0 = "".concat(key);
              selectedItems.level1 = "".concat(key, "-").concat(i);
              matchFound = true;
              break;
            } else {
              var _menu$i2;
              var links = (_menu$i2 = menu[i]) === null || _menu$i2 === void 0 || (_menu$i2 = _menu$i2.megapanelContent) === null || _menu$i2 === void 0 || (_menu$i2 = _menu$i2.quickLinks) === null || _menu$i2 === void 0 ? void 0 : _menu$i2.links;
              for (var k = 0; k < (links === null || links === void 0 ? void 0 : links.length); k++) {
                var _links$k;
                if (((_links$k = links[k]) === null || _links$k === void 0 ? void 0 : _links$k.url) === currentUrlPath) {
                  selectedItems.level0 = "".concat(key);
                  selectedItems.level1 = "".concat(key, "-").concat(i);
                  selectedItems.level2 = "".concat(key, "-").concat(i, "-").concat(k);
                  matchFound = true;
                  break;
                }
              }
            }
          }
        }
        return selectedItems;
      }
      return selectedItems;
    };
  };
  var selectedUrlCheck = _selectedLeftNavItems();

  /**
   * Keep track of which menu section is visible/expanded and ties current visible panel
   * back to its parent menu panel
   *
   * Example interaction and menuState change:
   * 1. When left nav is first opened - default state --> {level0: -1, level1: -1}
   * 2. User then clicks on first menu item (item index is 0) --> {level0: 0, level1: -1}
   * 3. User then clicks on second menu item (item index is 1) of current visible panel --> {level0: 0, level1: 1}
   * 4. User then clicks back button --> {level0: 0, level1: -1}
   * 5. User then clicks back button again, going back to first panel --> {level0: -1, level1: -1}
   */
  var _useState = useState({
      level0: -1,
      level1: -1
    }),
    _useState2 = _slicedToArray(_useState, 2),
    menuState = _useState2[0],
    setMenuState = _useState2[1];

  // reset the left nav to default menu section when closed
  useEffect(function () {
    if (!isSideNavExpanded) {
      setMenuState({
        level0: -1,
        level1: -1
      });
    }
  }, [isSideNavExpanded]);
  var sideNavRef = useRef();
  var level0Items = [];
  var level1Items = [];
  var sideNav = function sideNav() {
    var _sideNavRef$current;
    var selectedItems;
    navigation.map(function (link, i) {
      var _link$menuSections, _link$menuSections2;
      var dataTitle = link.titleEnglish ? link.titleEnglish.replace(/[^-a-zA-Z0-9_ ]/g, '').replace(/ +/g, '-').toLowerCase() : null;
      var autoid = "".concat(stablePrefix, "--masthead-").concat(rest.navType, "-sidenav__").concat(rest.hasL1Data ? 'l1' : 'l0', "-nav").concat(i);
      var menuItems = (_link$menuSections = link.menuSections) === null || _link$menuSections === void 0 || (_link$menuSections = _link$menuSections[0]) === null || _link$menuSections === void 0 ? void 0 : _link$menuSections.menuItems;
      selectedItems = selectedUrlCheck({
        menu: menuItems,
        key: i,
        parentItemUrl: link.url
      });
      if (link.hasMenu || link.hasMegaPanel || ((_link$menuSections2 = link.menuSections) === null || _link$menuSections2 === void 0 ? void 0 : _link$menuSections2.length) !== 0) {
        var _selectedItems;
        level1Items.push({
          title: link.title,
          autoid: autoid,
          parentKey: i,
          sections: link.menuSections
        });
        level0Items.push( /*#__PURE__*/React.createElement(SideNavMenu, {
          autoid: autoid,
          dataTitle: dataTitle,
          key: link.title,
          title: link.title,
          selected: !rest.selectedMenuItem ? ((_selectedItems = selectedItems) === null || _selectedItems === void 0 ? void 0 : _selectedItems.level0) === "".concat(i) : rest.selectedMenuItem === link.titleEnglish,
          onToggle: function onToggle() {
            return setMenuState(_objectSpread(_objectSpread({}, menuState), {}, {
              level0: i
            }));
          },
          isSideNavExpanded: i === menuState.level0 && menuState.level1 == -1
        }));
      } else {
        var _selectedItems2;
        level0Items.push( /*#__PURE__*/React.createElement(SideNavMenuItem, {
          href: link.url,
          className: (!rest.selectedMenuItem ? ((_selectedItems2 = selectedItems) === null || _selectedItems2 === void 0 ? void 0 : _selectedItems2.level0) === "".concat(i) : rest.selectedMenuItem === link.titleEnglish) && "".concat(prefix, "--masthead__side-nav--submemu--selected") || null,
          "data-autoid": autoid,
          key: link.title,
          role: "menuitem"
        }, link.title));
      }
    });
    var level1 = _renderLevel1Submenus(level1Items, backButtonText, setMenuState, menuState, rest.navType, rest.selectedMenuItem, selectedItems);
    var level2Submenus = _renderLevel2Submenus(level1.submenus, backButtonText, setMenuState, menuState, rest.navType, rest.selectedMenuItem, selectedItems);
    return /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(SideNavMenuSection, {
      id: "panel__(-1,-1)",
      focusNode: (_sideNavRef$current = sideNavRef.current) === null || _sideNavRef$current === void 0 ? void 0 : _sideNavRef$current.parentNode.querySelector(".".concat(prefix, "--header__menu-toggle")),
      show: menuState.level0 === -1
    }, level0Items), level1.menuSections, level2Submenus);
  };
  return /*#__PURE__*/React.createElement(SideNav, {
    "aria-label": "Side navigation",
    expanded: isSideNavExpanded,
    isPersistent: false,
    ref: sideNavRef,
    onOverlayClick: rest.onOverlayClick
  }, /*#__PURE__*/React.createElement("nav", {
    "data-autoid": "".concat(stablePrefix, "--masthead-").concat(rest.navType, "-sidenav__l0")
  }, platform && /*#__PURE__*/React.createElement("a", {
    "data-autoid": "".concat(stablePrefix, "--masthead-").concat(rest.navType, "-sidenav__l0-productname"),
    href: platform.url,
    className: cx("".concat(prefix, "--side-nav__submenu"), "".concat(prefix, "--side-nav__submenu-platform"))
  }, platform.name), /*#__PURE__*/React.createElement(SideNavItems, null, /*#__PURE__*/React.createElement(HeaderSideNavItems, null, sideNav()))));
};

/**
 * Loops through and renders a list of links for the side nav
 *
 * @param {Array} menuItems menu items
 * @param {string} backButtonText back button text
 * @param {Function} setMenuState setState func
 * @param {object} menuState currrent menu that is visible
 * @param {string} navType navigation type
 * @param {string} selectedMenuItem inputted selected menu item
 * @param {object} selectedItems selected menu items based on url
 * @returns {object} JSX object
 */
function _renderLevel1Submenus(menuItems, backButtonText, setMenuState, menuState, navType, selectedMenuItem, selectedItems) {
  // gather submenu items for next level
  var submenus = [];
  var sideNavMenuSections = menuItems.map(function (menu, i) {
    var _menu$sections, _menu$sections2;
    // get array of highlighted menu items to render first
    var highlightedItems = [];
    var items = [];
    (_menu$sections = menu.sections) === null || _menu$sections === void 0 || _menu$sections[0].menuItems.forEach(function (item) {
      if (item.highlighted) return highlightedItems.push(item);
      return items.push(item);
    });
    var sortedMenu = highlightedItems.concat(items);
    var highlightedCount = highlightedItems.length;
    return /*#__PURE__*/React.createElement(SideNavMenuSection, {
      isSubmenu: true,
      className: cx(_defineProperty(_defineProperty({}, "".concat(prefix, "--side-nav__menu-section-submenu"), true), "".concat(prefix, "--side-nav__menu-section-submenu--expanded"), menuState.level0 === menu.parentKey && menuState.level1 >= 0)),
      id: "panel__(".concat(menu.parentKey, ",-1)"),
      heading: (_menu$sections2 = menu.sections) === null || _menu$sections2 === void 0 || (_menu$sections2 = _menu$sections2[0]) === null || _menu$sections2 === void 0 ? void 0 : _menu$sections2.heading,
      key: menu.title,
      title: menu.title,
      navType: navType,
      backButtonText: backButtonText,
      onBackClick: function onBackClick() {
        return setMenuState({
          level0: -1,
          level1: -1
        });
      },
      show: menuState.level0 === menu.parentKey && menuState.level1 === -1
    }, sortedMenu.map(function (item, index) {
      var _item$megapanelConten;
      submenus.push({
        title: item.title,
        titleUrl: item.url,
        autoid: "".concat(menu.autoid, "-list").concat(index),
        sections: (_item$megapanelConten = item.megapanelContent) === null || _item$megapanelConten === void 0 || (_item$megapanelConten = _item$megapanelConten.quickLinks) === null || _item$megapanelConten === void 0 ? void 0 : _item$megapanelConten.links,
        parentKey: menu.parentKey,
        index: index
      });
      var highlightedClass = highlightedCount !== 0 && index + 1 === highlightedCount && "".concat(prefix, "--masthead__side-nav__last-highlighted") || null;
      if (item.megapanelContent) {
        return /*#__PURE__*/React.createElement(SideNavMenu, {
          autoid: "".concat(menu.autoid, "-list").concat(index),
          title: item.title,
          key: item.title,
          selected: !selectedMenuItem && (selectedItems === null || selectedItems === void 0 ? void 0 : selectedItems.level1) === "".concat(menu.parentKey, "-").concat(index),
          className: highlightedClass,
          onToggle: function onToggle() {
            return setMenuState(_objectSpread(_objectSpread({}, menuState), {}, {
              level1: index
            }));
          },
          isSideNavExpanded: i === menuState.level0 && menuState.level1 == index
        });
      }
      return /*#__PURE__*/React.createElement(SideNavMenuItem, _defineProperty(_defineProperty({
        href: item.url,
        className: highlightedClass,
        "data-autoid": "".concat(menu.autoid, "-list").concat(index),
        key: item.title
      }, "className", !selectedMenuItem && (selectedItems === null || selectedItems === void 0 ? void 0 : selectedItems.level1) === "".concat(menu.parentKey, "-").concat(index) && "".concat(prefix, "--masthead__side-nav--submemu--selected") || null), "role", "menuitem"), item.title);
    }));
  });
  return {
    menuSections: sideNavMenuSections,
    submenus: submenus
  };
}

/**
 * Loops through and renders a list of links for the side nav
 *
 * @param {Array} menuItems menu items
 * @param {string} backButtonText back button text
 * @param {Function} setMenuState setState func
 * @param {object} menuState currrent menu that is visible
 * @param {string} navType navigation type
 * @param {string} selectedMenuItem inputted selected menu item
 * @param {object} selectedItems selected menu items based on url
 * @returns {object} JSX object
 */
function _renderLevel2Submenus(menuItems, backButtonText, setMenuState, menuState, navType, selectedMenuItem, selectedItems) {
  var sideNavMenuSections = menuItems.map(function (menu) {
    var _menu$sections3;
    return /*#__PURE__*/React.createElement(SideNavMenuSection, {
      isSubmenu: true,
      className: "".concat(prefix, "--side-nav__menu-section-submenu"),
      id: "panel__(".concat(menu.parentKey, ",").concat(menu.index, ")"),
      key: menu.title,
      title: menu.title,
      titleUrl: menu.titleUrl,
      navType: navType,
      backButtonText: backButtonText,
      onBackClick: function onBackClick() {
        return setMenuState(_objectSpread(_objectSpread({}, menuState), {}, {
          level1: -1
        }));
      },
      show: menuState.level0 === menu.parentKey && menuState.level1 === menu.index
    }, (_menu$sections3 = menu.sections) === null || _menu$sections3 === void 0 ? void 0 : _menu$sections3.map(function (item, k) {
      return /*#__PURE__*/React.createElement(SideNavMenuItem, {
        href: item.url,
        "data-autoid": "".concat(menu.autoid, "-item").concat(k),
        key: item.title,
        className: !selectedMenuItem && (selectedItems === null || selectedItems === void 0 ? void 0 : selectedItems.level2) === "".concat(menu.parentKey, "-").concat(menu.index, "-").concat(k) && "".concat(prefix, "--masthead__side-nav--submemu--selected") || null,
        role: "menuitem"
      }, item.title);
    }));
  });
  return sideNavMenuSections;
}
MastheadLeftNav.propTypes = {
  /**
   * Back button text
   */
  backButtonText: PropTypes.string,
  /**
   * Object containing left navigation elements.
   */
  navigation: PropTypes.arrayOf(PropTypes.shape({
    hasMenu: PropTypes.bool,
    title: PropTypes.string,
    url: PropTypes.string,
    menuSections: PropTypes.arrayOf(PropTypes.shape({
      menuItems: PropTypes.arrayOf(PropTypes.shape({
        title: PropTypes.string,
        url: PropTypes.string
      }))
    }))
  })),
  /**
   * `true` to make the sidenav expanded.
   */
  isSideNavExpanded: PropTypes.bool,
  /**
   * Platform object with name and url
   */
  platform: PropTypes.shape({
    name: PropTypes.string,
    url: PropTypes.string
  })
};
MastheadLeftNav.defaultProps = {
  backButtonText: 'Back'
};
export default MastheadLeftNav;