import _asyncToGenerator from "@babel/runtime/helpers/asyncToGenerator";
import _classCallCheck from "@babel/runtime/helpers/classCallCheck";
import _createClass from "@babel/runtime/helpers/createClass";
import _regeneratorRuntime from "@babel/runtime/regenerator";
/**
 * Copyright IBM Corp. 2021, 2022
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
import axios from 'axios';
import Cookies from 'js-cookie';

/**
 * The cookie name for determining user login status for cloud.ibm.com.
 *
 * @type {string}
 * @private
 */
var _cookieName = 'com.ibm.cloud.iam.LoggedIn.prod';
var CloudAccountAuthAPI = /*#__PURE__*/function () {
  function CloudAccountAuthAPI() {
    _classCallCheck(this, CloudAccountAuthAPI);
  }
  _createClass(CloudAccountAuthAPI, null, [{
    key: "checkCookie",
    value:
    /**
     * retrieve the cloud login status via cookie
     *
     * @example
     * import { cloudAccountAuthentication } from '@carbon/ibmdotcom-utilities';
     *
     * const status = cloudAccountAuthentication.checkCookie();
     * @returns {string} string determining login status
     */
    function checkCookie() {
      var cloudLogin = Cookies.get(_cookieName);
      return {
        user: cloudLogin === '1' ? 'authenticated' : 'anonymous'
      };
    }

    /**
     * retrieve the cloud login status via api
     *
     * @example
     * import { cloudAccountAuthentication } from '@carbon/ibmdotcom-utilities';
     *
     * const status = cloudAccountAuthentication.checkAPI();
     * @returns {string} string determining login status
     */
  }, {
    key: "checkAPI",
    value: function () {
      var _checkAPI = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
        var cloudLogin;
        return _regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) switch (_context.prev = _context.next) {
            case 0:
              _context.next = 2;
              return axios.get('/api/v6/selected-account?profile=true', {
                headers: {
                  Accept: 'application/json'
                }
              }).then(function (response) {
                return response.status === 200 ? 'authenticated' : 'anonymous';
              }).catch(function (error) {
                console.error(error);
                return 'anonymous';
              });
            case 2:
              cloudLogin = _context.sent;
              return _context.abrupt("return", {
                user: cloudLogin
              });
            case 4:
            case "end":
              return _context.stop();
          }
        }, _callee);
      }));
      function checkAPI() {
        return _checkAPI.apply(this, arguments);
      }
      return checkAPI;
    }()
  }]);
  return CloudAccountAuthAPI;
}();
export default CloudAccountAuthAPI;