"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
var _typeof = require("@babel/runtime/helpers/typeof");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));
var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));
var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutProperties"));
var _react = _interopRequireWildcard(require("react"));
var _ButtonGroup = require("../ButtonGroup");
var _CTALogic = _interopRequireDefault(require("./CTALogic"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _excluded = ["type", "openLightBox", "renderLightBox", "videoTitle", "formatCTAcopy"];
/**
 * Copyright IBM Corp. 2016, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != _typeof(e) && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && Object.prototype.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { (0, _defineProperty2.default)(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
/**
 * Button subcomponent for CTA.
 */
var ButtonCTA = function ButtonCTA(_ref) {
  var type = _ref.type,
    openLightBox = _ref.openLightBox,
    renderLightBox = _ref.renderLightBox,
    videoTitle = _ref.videoTitle,
    formatCTAcopy = _ref.formatCTAcopy,
    otherProps = (0, _objectWithoutProperties2.default)(_ref, _excluded);
  var _useState = (0, _react.useState)({}),
    _useState2 = (0, _slicedToArray2.default)(_useState, 2),
    mediaData = _useState2[0],
    setMediaData = _useState2[1];
  return type.includes('video') ? /*#__PURE__*/_react.default.createElement("div", null, _CTALogic.default.launchLightBox(renderLightBox, openLightBox, mediaData), !renderLightBox && /*#__PURE__*/_react.default.createElement(_ButtonGroup.ButtonGroup, {
    buttons: _renderButtons(_objectSpread({
      videoTitle: videoTitle,
      openLightBox: openLightBox,
      setMediaData: setMediaData,
      formatCTAcopy: formatCTAcopy
    }, otherProps))
  })) : /*#__PURE__*/_react.default.createElement(_ButtonGroup.ButtonGroup, {
    buttons: _renderButtons(_objectSpread({}, otherProps))
  });
};

/**
 * sets button
 *
 * @param {object} param param object
 * @param {Function} param.openLightBox func to set renderLightBox state
 * @param {Array} param.videoTitle array of video titles
 * @param {Function} param.setMediaData func to set media data state
 * @param {Function} param.formatCTAcopy func to format the cta copy
 * @param {object} param.buttons object with buttons array
 * @private
 * @returns {*} object
 */
var _renderButtons = function _renderButtons(_ref2) {
  var openLightBox = _ref2.openLightBox,
    videoTitle = _ref2.videoTitle,
    setMediaData = _ref2.setMediaData,
    formatCTAcopy = _ref2.formatCTAcopy,
    buttons = _ref2.buttons;
  return buttons.map(function (button, key) {
    if (button.type === 'video') {
      button.onClick = function (e) {
        e.preventDefault();
        setMediaData(button.media);
        return _CTALogic.default.setLightBox(e, openLightBox);
      };
      var title = videoTitle.filter(function (name) {
        return name.key === key;
      });
      button.copy = !title[0] ? button.copy : formatCTAcopy({
        title: (button === null || button === void 0 ? void 0 : button.media.title) || title[0].title,
        duration: title[0].duration
      });
      button.href = '#';
    } else {
      button.onClick = button.onClick || function (e) {
        return _CTALogic.default.jump(e, button.type);
      };
      button.target = _CTALogic.default.external(button.type);
    }
    button.renderIcon = _CTALogic.default.iconSelector(button.type);
    button.iconDescription = _renderIconDesc(button.type);
    return button;
  });
};

/**
 * render the icon description for screen reader
 *
 * @param {string} type type of cta
 * @private
 * @returns {string} icon description
 */
var _renderIconDesc = function _renderIconDesc(type) {
  switch (type) {
    case 'external':
      return 'external launch icon';
    case 'jump':
      return 'down arrow icon';
    case 'video':
      return 'play button icon';
    default:
      return 'right arrow icon';
  }
};
ButtonCTA.propTypes = {
  /**
   * CTA type. Choose from:
   *
   * | Type       | SVG element Name | Description                                                      |
   * | ---------- | ---------------- | ---------------------------------------------------------------- |
   * | `local`    | ArrowRight20     | Describes right arrow onClick which loads in self page.          |
   * | `jump`     | ArrowDown20      | Describes down arrow onClick which scrollToView of target.       |
   * | `external` | Launch20         | Describes launch arrow onClick which loads in new tab.           |
   * | `download` | Download20       | Describes download arrow onClick for downloading files.          |
   * | `video`    | PlayOutline20    | Describes play icon onClick which loads the video in a lightbox. |
   * | `default`  | None             | Describes the default CTA - without icon                         |
   *
   * For more details of icons, refer to:
   *
   * - [Icons library](https://www.carbondesignsystem.com/guidelines/icons/library/)!👀
   * - [@carbon/icons-react](https://github.com/carbon-design-system/carbon/tree/v1/packages/icons-react)!👀
   * - [carbon-icons](https://www.npmjs.com/package/carbon-icons)!👀
   */
  type: _propTypes.default.oneOfType([_propTypes.default.oneOf(['jump', 'local', 'external', 'download', 'video', 'default']), _propTypes.default.arrayOf(_propTypes.default.oneOf(['jump', 'local', 'external', 'download', 'video', 'default']))]),
  /**
   * Array of button objects to render.
   */
  buttons: _propTypes.default.arrayOf(_propTypes.default.shape({
    type: _propTypes.default.oneOf(['local', 'external', 'jump', 'video']),
    copy: _propTypes.default.string,
    href: _propTypes.default.string,
    mediaData: _propTypes.default.shape({
      customClassName: _propTypes.default.string,
      videoId: _propTypes.default.string.isRequired,
      showCaption: _propTypes.default.bool,
      inverse: _propTypes.default.bool
    })
  })).isRequired,
  /**
   * Func to set renderLightBox state.
   */
  openLightBox: _propTypes.default.func,
  /**
   * Bool to determine whether to open lightbox.
   */
  renderLightBox: _propTypes.default.bool,
  /**
   * Array of video titles.
   */
  videoTitle: _propTypes.default.arrayOf(_propTypes.default.shape({
    title: _propTypes.default.string,
    duration: _propTypes.default.string,
    key: _propTypes.default.oneOfType([_propTypes.default.number, _propTypes.default.string])
  })),
  /**
   * The function to set media data.
   */
  setMediaData: _propTypes.default.func,
  /**
   * Func to format the cta copy
   */
  formatCTAcopy: _propTypes.default.func
};
ButtonCTA.defaultProps = {
  type: 'default',
  formatCTAcopy: function formatCTAcopy(_ref3) {
    var title = _ref3.title,
      duration = _ref3.duration;
    return "".concat(title, " ").concat(duration);
  }
};
var _default = exports.default = ButtonCTA;