"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));
var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutProperties"));
var _CTALogic = _interopRequireDefault(require("./CTALogic"));
var _FeatureCard = require("../FeatureCard");
var _propTypes = _interopRequireDefault(require("prop-types"));
var _react = _interopRequireDefault(require("react"));
var _excluded = ["size", "type", "openLightBox", "renderLightBox", "videoTitle", "formatCTAcopy"];
/**
 * Copyright IBM Corp. 2016, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { (0, _defineProperty2.default)(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
/**
 * FeatureCard subcomponent for CTA.
 */
var FeatureCTA = function FeatureCTA(_ref) {
  var size = _ref.size,
    type = _ref.type,
    openLightBox = _ref.openLightBox,
    renderLightBox = _ref.renderLightBox,
    videoTitle = _ref.videoTitle,
    formatCTAcopy = _ref.formatCTAcopy,
    otherProps = (0, _objectWithoutProperties2.default)(_ref, _excluded);
  return type === 'video' ? /*#__PURE__*/_react.default.createElement("div", null, _CTALogic.default.launchLightBox(renderLightBox, openLightBox, otherProps.card.cta.media), !renderLightBox && /*#__PURE__*/_react.default.createElement(_FeatureCard.FeatureCard, {
    card: _renderFeatureCard({
      card: _objectSpread(_objectSpread({}, otherProps.card), {}, {
        heading: formatCTAcopy({
          title: videoTitle[0].title,
          duration: videoTitle[0].duration
        })
      })
    }),
    size: size,
    onClick: function onClick(e) {
      return _CTALogic.default.setLightBox(e, openLightBox);
    }
  })) : /*#__PURE__*/_react.default.createElement(_FeatureCard.FeatureCard, {
    card: _renderFeatureCard({
      card: _objectSpread({}, otherProps.card)
    }),
    size: size
  });
};

/**
 * sets featureCard
 *
 * @param {object} param param object
 * @param {object} param.card card object
 * @private
 * @returns {*} object
 */
var _renderFeatureCard = function _renderFeatureCard(_ref2) {
  var card = _ref2.card;
  if (card.type === 'jump') card.cta.type = 'jump';else if (card.type === 'video') card.cta.href = '#';
  card.cta = _objectSpread(_objectSpread({}, card.cta), {}, {
    icon: {
      src: _CTALogic.default.iconSelector(card.cta.type)
    }
  });
  card.type = 'link';
  return card;
};
FeatureCTA.propTypes = {
  /**
   * Size of Feature Card. Choose from:
   *
   * | Name    | Description                                                  |
   * | ------- | -------------------------------------------------------------|
   * | `medium`| Default Feature Card variant                                 |
   * | `large` | Large Feature Card variant that contains eyebrow and heading |
   */
  size: _propTypes.default.oneOf(['medium', 'large']),
  /**
   * CTA type. Choose from:
   *
   * | Type       | SVG element Name | Description                                                      |
   * | ---------- | ---------------- | ---------------------------------------------------------------- |
   * | `local`    | ArrowRight20     | Describes right arrow onClick which loads in self page.          |
   * | `jump`     | ArrowDown20      | Describes down arrow onClick which scrollToView of target.       |
   * | `external` | Launch20         | Describes launch arrow onClick which loads in new tab.           |
   * | `download` | Download20       | Describes download arrow onClick for downloading files.          |
   * | `video`    | PlayOutline20    | Describes play icon onClick which loads the video in a lightbox. |
   * | `default`  | None             | Describes the default CTA - without icon                         |
   *
   * For more details of icons, refer to:
   *
   * - [Icons library](https://www.carbondesignsystem.com/guidelines/icons/library/)!👀
   * - [@carbon/icons-react](https://github.com/carbon-design-system/carbon/tree/v1/packages/icons-react)!👀
   * - [carbon-icons](https://www.npmjs.com/package/carbon-icons)!👀
   */
  type: _propTypes.default.oneOfType([_propTypes.default.oneOf(['jump', 'local', 'external', 'download', 'video', 'default']), _propTypes.default.arrayOf(_propTypes.default.oneOf(['jump', 'local', 'external', 'download', 'video', 'default']))]),
  /**
   * Func to set renderLightBox state.
   */
  openLightBox: _propTypes.default.func,
  /**
   * Bool to determine whether to open lightbox.
   */
  renderLightBox: _propTypes.default.bool,
  /**
   * Array of video titles.
   */
  videoTitle: _propTypes.default.arrayOf(_propTypes.default.shape({
    title: _propTypes.default.string,
    duration: _propTypes.default.string,
    key: _propTypes.default.oneOfType([_propTypes.default.number, _propTypes.default.string])
  })),
  /**
   * Func to format the cta copy
   */
  formatCTAcopy: _propTypes.default.func
};
FeatureCTA.defaultProps = {
  type: 'default',
  formatCTAcopy: function formatCTAcopy(_ref3) {
    var title = _ref3.title,
      duration = _ref3.duration;
    return "".concat(title, " ").concat(duration);
  }
};
var _default = exports.default = FeatureCTA;