"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
var _typeof = require("@babel/runtime/helpers/typeof");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));
var _react = _interopRequireWildcard(require("react"));
var _settings = _interopRequireDefault(require("../../internal/vendor/@carbon/ibmdotcom-utilities/utilities/settings/settings"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _settings2 = _interopRequireDefault(require("carbon-components/umd/globals/js/settings"));
var _smoothScroll = _interopRequireDefault(require("../../internal/vendor/@carbon/ibmdotcom-utilities/utilities/smoothScroll/smoothScroll"));
var _ = _interopRequireDefault(require("@carbon/icons-react/lib/table-of-contents/20"));
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != _typeof(e) && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && Object.prototype.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/**
 * Copyright IBM Corp. 2016, 2023
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

var stablePrefix = _settings.default.stablePrefix;
var prefix = _settings2.default.prefix;

/**
 * Mobile Component.
 */
var TOCMobile = function TOCMobile(_ref) {
  var menuItems = _ref.menuItems,
    selectedId = _ref.selectedId,
    menuLabel = _ref.menuLabel,
    updateState = _ref.updateState;
  var _useState = (0, _react.useState)('menuLabel'),
    _useState2 = (0, _slicedToArray2.default)(_useState, 2),
    selectedOption = _useState2[0],
    setSelectedOption = _useState2[1];
  (0, _react.useEffect)(function () {
    setSelectedOption(selectedId);
  }, [selectedId]);

  /**
   * Handle onChange event of select
   *
   * @param {*} e event object
   */
  var handleChange = function handleChange(e) {
    var id = e.target.value;
    var filteredItems = menuItems.filter(function (menu) {
      return menu.id === id;
    });
    var title = filteredItems[0].title;
    updateState(id, title);
    var selector = "a[name=\"".concat(id, "\"]");
    (0, _smoothScroll.default)(null, selector, 50);
    triggerFocus(selector);
  };

  /**
   * Trigger the focus on screen readers, so they can read the target paragraph
   *
   * @param {*} elem Selector to find the item
   */
  function triggerFocus(elem) {
    var element = document.querySelector(elem);
    if (element) {
      var handleFocusOut = function handleFocusOut(event) {
        var focusoutTarget = event.target;
        focusoutTarget.removeAttribute('tabindex');
      };
      element.setAttribute('tabindex', '0');
      element.focus({
        preventScroll: true
      });
      element.addEventListener('focusout', handleFocusOut, {
        once: true
      });
    }
  }

  /**
   * Handle OnBlur event
   *
   * @returns {null} Returns null for blur events
   */
  var handleOnBlur = function handleOnBlur() {
    return null;
  };
  return /*#__PURE__*/_react.default.createElement("div", {
    className: "".concat(prefix, "--tableofcontents__mobile"),
    "data-autoid": "".concat(stablePrefix, "--tableofcontents__mobile")
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: "".concat(prefix, "--tableofcontents__mobile__select__wrapper")
  }, /*#__PURE__*/_react.default.createElement("select", {
    "aria-label": menuLabel,
    className: "".concat(prefix, "--tableofcontents__mobile__select"),
    onBlur: handleOnBlur,
    value: selectedOption,
    onChange: function onChange(e) {
      return handleChange(e);
    }
  }, renderOptions(menuItems, menuLabel)), /*#__PURE__*/_react.default.createElement(_.default, {
    className: "".concat(prefix, "--tableofcontents__mobile__select__icon"),
    "aria-label": "menu icon"
  }, /*#__PURE__*/_react.default.createElement("title", null, "menu icon"))));
};

/**
 * Render options for select
 *
 * @param {Array} options menu item arrray
 * @param {Array} label menu label
 * @returns {*} JSX Object
 */
var renderOptions = function renderOptions(options, label) {
  var labelObj = {
    title: "".concat(label, " ..."),
    id: 'menuLabel'
  };
  options.findIndex(function (x) {
    return x.id === labelObj.id;
  }) === -1 ? options.unshift(labelObj) : null;
  return options.map(function (option, index) {
    if (option) {
      return /*#__PURE__*/_react.default.createElement("option", {
        className: "".concat(prefix, "--tableofcontents__mobile__select__option"),
        "data-autoid": "".concat(stablePrefix, "--tableofcontents__mobile__select__option-").concat(option.id),
        key: index,
        value: option.id,
        defaultValue: index === 0,
        disabled: index === 0,
        hidden: index === 0
      }, option.title);
    }
  });
};
TOCMobile.propTypes = {
  /**
   * Array of menu item objects to render within the side nav.
   * Each items has the following structure:
   *
   * | Properties Name | Data Type | Description     |
   * | --------------- | --------- | --------------- |
   * | title           | String    | Menu title text |
   * | id              | String    | Menu id         |
   */
  menuItems: _propTypes.default.array,
  /**
   * Id of a menu item.
   */
  selectedId: _propTypes.default.string,
  /**
   * Menu label for mobile menu.
   */
  menuLabel: _propTypes.default.string,
  /**
   * Function to update parent state.
   */
  updateState: _propTypes.default.func
};
var _default = exports.default = TOCMobile;