"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _layout = require("@carbon/layout");
var _settings = _interopRequireDefault(require("../settings/settings.js"));
var _windowOrGlobal = _interopRequireDefault(require("window-or-global"));
var _settings2 = _interopRequireDefault(require("carbon-components/umd/globals/js/settings"));
function _typeof(o) {
  "@babel/helpers - typeof";

  return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) {
    return typeof o;
  } : function (o) {
    return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o;
  }, _typeof(o);
}
function _classCallCheck(instance, Constructor) {
  if (!(instance instanceof Constructor)) {
    throw new TypeError("Cannot call a class as a function");
  }
}
function _defineProperties(target, props) {
  for (var i = 0; i < props.length; i++) {
    var descriptor = props[i];
    descriptor.enumerable = descriptor.enumerable || false;
    descriptor.configurable = true;
    if ("value" in descriptor) descriptor.writable = true;
    Object.defineProperty(target, _toPropertyKey(descriptor.key), descriptor);
  }
}
function _createClass(Constructor, protoProps, staticProps) {
  if (protoProps) _defineProperties(Constructor.prototype, protoProps);
  if (staticProps) _defineProperties(Constructor, staticProps);
  Object.defineProperty(Constructor, "prototype", {
    writable: false
  });
  return Constructor;
}
function _toPropertyKey(arg) {
  var key = _toPrimitive(arg, "string");
  return _typeof(key) === "symbol" ? key : String(key);
}
function _toPrimitive(input, hint) {
  if (_typeof(input) !== "object" || input === null) return input;
  var prim = input[Symbol.toPrimitive];
  if (prim !== undefined) {
    var res = prim.call(input, hint || "default");
    if (_typeof(res) !== "object") return res;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return (hint === "string" ? String : Number)(input);
}
/**
 * Copyright IBM Corp. 2016, 2023
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

var prefix = _settings2.default.prefix;
var ddsPrefix = _settings.default.stablePrefix;
var gridBreakpoint = parseFloat(_layout.breakpoints.lg.width) * _layout.baseFontSize;
var StickyHeader = /*#__PURE__*/function () {
  function StickyHeader() {
    _classCallCheck(this, StickyHeader);
    this.ownerDocument = _windowOrGlobal.default.document;
    this._banner = undefined;
    this._cumulativeHeight = 0;
    this._hasBanner = false;
    this._lastScrollPosition = 0;
    this._leadspaceWithSearch = undefined;
    this._leadspaceSearchBar = undefined;
    this._leadspaceWithSearchStickyThreshold = 0;
    this._localeModal = undefined;
    this._masthead = undefined;
    this._mastheadL0 = undefined;
    this._mastheadL1 = undefined;
    this._tableOfContents = undefined;
    this._tableOfContentsInnerBar = undefined;
    this._tableOfContentsLayout = undefined;
    this._throttled = false;
    this._resizeObserver = new ResizeObserver(this._handleResize.bind(this));
    _windowOrGlobal.default.addEventListener('scroll', this._throttledHandler.bind(this));
  }

  /**
   * Create (if needed) and return the globally-scoped instance of `this`.
   */
  _createClass(StickyHeader, [{
    key: "height",
    get: function get() {
      return this._cumulativeHeight;
    }

    /**
     * Compares the tag name of the component provided to what we expect it to be
     *
     * @param {HTMLElement} component The component provided
     * @param {string} expected The lowercase tag name expected
     * @throws {TypeError} Throws error if component tag name doesn't match expected string
     * @returns {boolean} Returns true if component tag name matches expected string
     */
  }, {
    key: "_validateComponent",
    value: function _validateComponent(component, expected) {
      var received = component.tagName.toLowerCase();
      if (received !== expected) {
        throw new TypeError("".concat(expected, " expected, ").concat(received, " provided"));
      } else {
        return true;
      }
    }
  }, {
    key: "_tableOfContentsStickyUpdate",
    value: function _tableOfContentsStickyUpdate() {
      var toc = this._tableOfContents;
      var tocRoot = toc.shadowRoot;
      var desktopSelector = ".".concat(ddsPrefix, "-ce--table-of-contents__items-container");
      if (window.innerWidth > gridBreakpoint) {
        if (toc.layout === 'horizontal') {
          this._tableOfContentsInnerBar = tocRoot.querySelector(".".concat(prefix, "--tableofcontents__navbar"));
          this._tableOfContentsLayout = 'horizontal';
        } else {
          this._tableOfContentsInnerBar = tocRoot.querySelector(desktopSelector);
        }
      } else {
        this._tableOfContentsInnerBar = tocRoot.querySelector(".".concat(prefix, "--tableofcontents__sidebar"));
      }
    }
  }, {
    key: "banner",
    set: function set(component) {
      if (this._validateComponent(component, "".concat(ddsPrefix, "-universal-banner"))) {
        this._banner = component;
        this.hasBanner = true;
        if (this._masthead) {
          this._masthead.setAttribute('with-banner', '');
        }
        this._calculateCumulativeHeight();
      }
    }
  }, {
    key: "leadspaceWithSearch",
    set: function set(component) {
      if (this._validateComponent(component, "".concat(ddsPrefix, "-leadspace-with-search"))) {
        this._leadspaceWithSearch = component;
        var leadspaceSearchBar = component.shadowRoot.querySelector(".".concat(prefix, "--search-container"));
        this._leadspaceSearchBar = leadspaceSearchBar;
        this._leadspaceWithSearchInput = component.querySelector("".concat(ddsPrefix, "-search-with-typeahead"));
        this._leadspaceWithSearchStickyThreshold = parseInt(window.getComputedStyle(leadspaceSearchBar).paddingBottom) - 16;
        this._calculateCumulativeHeight();
      }
    }
  }, {
    key: "localeModal",
    set: function set(component) {
      if (this._validateComponent(component, "".concat(ddsPrefix, "-locale-modal"))) {
        this._localeModal = component;
        this._calculateCumulativeHeight();
      }
    }
  }, {
    key: "masthead",
    set: function set(component) {
      if (this._validateComponent(component, "".concat(ddsPrefix, "-masthead"))) {
        this._masthead = component;
        if (this._banner) this._masthead.setAttribute('with-banner', '');
        this._mastheadL0 = component.shadowRoot.querySelector(".".concat(prefix, "--masthead__l0"));
        this._mastheadL1 = component.querySelector("".concat(ddsPrefix, "-masthead-l1"));
        this._calculateCumulativeHeight();
      }
    }
  }, {
    key: "tableOfContents",
    set: function set(component) {
      if (this._validateComponent(component, "".concat(ddsPrefix, "-table-of-contents"))) {
        this._tableOfContents = component;
        this._tableOfContentsStickyUpdate();
        this._resizeObserver.observe(this._tableOfContents);
        this._calculateCumulativeHeight();
      }
    }

    /**
     * Rate-limits the scroll event handler
     */
  }, {
    key: "_throttledHandler",
    value: function _throttledHandler() {
      var _this = this;
      if (!this._throttled) {
        this._throttled = true;
        this._calculateCumulativeHeight();
        setTimeout(function () {
          _this._throttled = false;
        }, 20);
      }
    }
  }, {
    key: "_handleResize",
    value: function _handleResize() {
      var hasBanner = this._hasBanner,
        masthead = this._masthead,
        toc = this._tableOfContents,
        tocLayout = this._tableOfContentsLayout,
        leadspaceSearchBar = this._leadspaceSearchBar;
      if (toc && masthead) {
        this._tableOfContentsStickyUpdate();
        if (window.innerWidth >= gridBreakpoint && tocLayout !== 'horizontal' && !hasBanner) {
          masthead.style.top = '0';
        } else {
          // This has to happen after the tocStickyUpdate method.
          var tocInner = this._tableOfContentsInnerBar;
          if (masthead.offsetTop === 0) {
            tocInner.style.top = "".concat(masthead.offsetHeight, "px");
          }
        }
        this._calculateCumulativeHeight();
      }
      if (leadspaceSearchBar) {
        this._leadspaceWithSearchStickyThreshold = parseInt(window.getComputedStyle(leadspaceSearchBar).paddingBottom) - 16;
      }
    }
  }, {
    key: "_calculateCumulativeHeight",
    value: function _calculateCumulativeHeight() {
      var _StickyHeader$global = StickyHeader.global,
        oldY = _StickyHeader$global._lastScrollPosition,
        banner = _StickyHeader$global._banner,
        masthead = _StickyHeader$global._masthead,
        mastheadL0 = _StickyHeader$global._mastheadL0,
        mastheadL1 = _StickyHeader$global._mastheadL1,
        localeModal = _StickyHeader$global._localeModal,
        toc = _StickyHeader$global._tableOfContents,
        tocInner = _StickyHeader$global._tableOfContentsInnerBar,
        leadspaceSearch = _StickyHeader$global._leadspaceWithSearch,
        leadspaceSearchBar = _StickyHeader$global._leadspaceSearchBar,
        leadspaceSearchInput = _StickyHeader$global._leadspaceWithSearchInput,
        leadspaceSearchThreshold = _StickyHeader$global._leadspaceWithSearchStickyThreshold;
      var customPropertyName = this.constructor.customPropertyName;
      if (localeModal && localeModal.hasAttribute('open')) return;
      var newY = window.scrollY;
      this._lastScrollPosition = Math.max(0, newY);

      /**
       * maxScrollaway is a calculated value matching the height of all components
       * that are allowed to hide above the viewport.
       *
       * We should only have one sticky header showing as the page scrolls down.
       *
       * Items that stick, in order
       * - L0
       * - L1
       * - The TOC in horizontal bar form
       * - The leadspace with search (if no TOC)
       */
      var maxScrollaway = 0;

      // Calculate maxScrollaway values based on TOC positon
      var tocIsAtTop = false;
      var tocShouldStick = false;
      if (tocInner) {
        tocIsAtTop = tocInner.getBoundingClientRect().top <= (masthead ? masthead.offsetTop + masthead.offsetHeight : 0) + 1;
        tocShouldStick = toc.layout === 'horizontal' || window.innerWidth < gridBreakpoint;
        if (masthead && tocIsAtTop && (tocShouldStick || mastheadL1)) {
          maxScrollaway += masthead.offsetHeight;
          if (mastheadL1 && !tocShouldStick) {
            maxScrollaway -= mastheadL1.offsetHeight;
          }
        } else if (mastheadL0 && mastheadL1) {
          maxScrollaway += mastheadL0.offsetHeight;
        }
      }

      // Calculate maxScrollaway values based on leadspace search position
      if (!tocInner && leadspaceSearchBar) {
        var searchIsAtTop = leadspaceSearchBar.getBoundingClientRect().top <= (masthead ? masthead.offsetTop + masthead.offsetHeight : 0) + 1;
        if (masthead && searchIsAtTop) {
          maxScrollaway += masthead.offsetHeight;
        }
      }

      /**
       * Cumulative offset is a calculated value used to set the `top` property of
       * components that stick to the top of the viewport.
       *
       * This value is equal to the difference between the previous scrollY and
       * the current scrollY values, but is positively and negatively limited.
       *
       * Positive limit: 0
       *   all elements visible, starting at the top of the viewport.
       *
       * Negative limit: maxScrollaway * -1
       *   all elements that should be hidden are positioned above the viewport
       *   with the elements that should be visible starting at the top of the
       *   viewport.
       */
      var cumulativeOffset = Math.max(Math.min((masthead ? masthead.offsetTop : 0) + oldY - newY, 0), maxScrollaway * -1);
      if (banner) {
        cumulativeOffset += Math.max(banner.offsetHeight - newY, 0);
      }
      if (masthead) {
        masthead.style.transition = 'none';
        masthead.style.top = "".concat(cumulativeOffset, "px");
        cumulativeOffset += masthead.offsetHeight;
      }
      if (tocInner) {
        tocInner.style.transition = 'none';
        tocInner.style.top = "".concat(cumulativeOffset, "px");
        tocShouldStick = toc.layout === 'horizontal' || window.innerWidth < gridBreakpoint;
        var tocIsStuck = Math.round(tocInner.getBoundingClientRect().top) <= cumulativeOffset + 1;
        if (tocShouldStick && tocIsStuck) {
          cumulativeOffset += tocInner.offsetHeight;
        }
      }
      if (!tocInner && leadspaceSearchBar) {
        var searchShouldBeSticky = leadspaceSearch.getBoundingClientRect().bottom <= leadspaceSearchThreshold;
        var searchIsSticky = leadspaceSearch.hasAttribute('sticky-search');
        if (searchShouldBeSticky) {
          if (!searchIsSticky) {
            leadspaceSearch.style.paddingBottom = "".concat(leadspaceSearchBar.offsetHeight, "px");
            leadspaceSearch.setAttribute('sticky-search', '');
            leadspaceSearchInput.setAttribute('large', '');
            window.requestAnimationFrame(function () {
              leadspaceSearchBar.style.transitionDuration = '110ms';
              leadspaceSearchBar.style.transform = 'translateY(0)';
            });
          }
          leadspaceSearchBar.style.top = "".concat(cumulativeOffset, "px");
          cumulativeOffset += leadspaceSearchBar.offsetHeight;
        }
        if (!searchShouldBeSticky && searchIsSticky) {
          leadspaceSearch.removeAttribute('sticky-search');
          leadspaceSearch.style.paddingBottom = '';
          leadspaceSearchBar.style.top = '';
          leadspaceSearchBar.style.transitionDuration = '';
          leadspaceSearchBar.style.transform = '';
          leadspaceSearchInput.removeAttribute('large');
        }
      }

      // Set internal property for use in scripts
      this._cumulativeHeight = cumulativeOffset;

      // Set custom property for use in stylesheets
      _windowOrGlobal.default.document.documentElement.style.setProperty(customPropertyName, "".concat(this._cumulativeHeight, "px"));
    }
  }], [{
    key: "global",
    get: function get() {
      if (!Object.prototype.hasOwnProperty.call(_windowOrGlobal.default, 'stickyHeader')) {
        _windowOrGlobal.default.stickyHeader = new StickyHeader();
      }
      return _windowOrGlobal.default.stickyHeader;
    }
  }, {
    key: "customPropertyName",
    get: function get() {
      return "--".concat(ddsPrefix, "-sticky-header-height");
    }
  }]);
  return StickyHeader;
}();
var _default = exports.default = StickyHeader;