"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _windowOrGlobal = _interopRequireDefault(require("window-or-global"));
/**
 * Copyright IBM Corp. 2020, 2022
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

/**
 * Utility to grab all alternative languages on the page. this scrapes the page
 * of all <link rel="alternate" hreflang="" href="" /> elements and returns
 * as a readable object
 *
 * @example
 * import { altlangs } from '@carbon/ibmdotcom-utilities';
 *
 * const langs = altlangs();
 *
 * console.log(langs); // { 'us-en': 'https://www.ibm.com/us-en', ... }
 * @returns {object} object of available languages and corresponding URLs
 */
function altlangs() {
  var links = [];
  var langs = {};
  if (_windowOrGlobal.default.document) {
    links = _windowOrGlobal.default.document.querySelectorAll('link[rel="alternate"]');
    links.forEach(function (link) {
      langs[link.getAttribute('hreflang')] = link.getAttribute('href');
    });
  }
  return langs;
}
var _default = exports.default = altlangs;