"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _regenerator = _interopRequireDefault(require("@babel/runtime/regenerator"));
var _asyncToGenerator2 = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));
var _classCallCheck2 = _interopRequireDefault(require("@babel/runtime/helpers/classCallCheck"));
var _createClass2 = _interopRequireDefault(require("@babel/runtime/helpers/createClass"));
var _axios = _interopRequireDefault(require("axios"));
/**
 * Copyright IBM Corp. 2020, 2022
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

/**
 * @constant {string | string} Host for the API calls
 * @private
 */
var _host = process && process.env.MARKETING_SEARCH_HOST || 'https://www.ibm.com';

/**
 * @constant {string | string} API version
 * @private
 */
var _version = process && process.env.MARKETING_SEARCH_VERSION || 'v3';

/**
 * MarketingSearch endpoint
 *
 * @type {string}
 * @private
 */
var _endpoint = "".concat(_host, "/marketplace/api/search/").concat(_version, "/combined_suggestions");

/**
 * MarketingSearch API class with methods of fetching search results for
 * ibm.com
 */
var MarketingSearchAPI = /*#__PURE__*/function () {
  function MarketingSearchAPI() {
    (0, _classCallCheck2.default)(this, MarketingSearchAPI);
  }
  (0, _createClass2.default)(MarketingSearchAPI, null, [{
    key: "getResults",
    value:
    /**
     * Gets search results for marketing
     *
     * @param {string} query Query string to pass to the service
     * @returns {Promise<any>} Response data from ibm search
     * @example
     * import { MarketingSearchAPI } from '@carbon/ibmdotcom-services';
     *
     * async function getResults(query) {
     *   const response = await MarketingSearchAPI.getResults(query);
     *   return response;
     * }
     */
    function () {
      var _getResults = (0, _asyncToGenerator2.default)( /*#__PURE__*/_regenerator.default.mark(function _callee(query) {
        var lc, cc, url;
        return _regenerator.default.wrap(function _callee$(_context) {
          while (1) switch (_context.prev = _context.next) {
            case 0:
              lc = 'en'; // TODO: create utility for fetching lc
              cc = 'us'; // TODO: create utility for fetching cc
              url = "".concat(_endpoint, "?locale=").concat(lc, "-").concat(cc, "&q=").concat(encodeURIComponent(query));
              _context.next = 5;
              return _axios.default.get(url, {
                headers: {
                  'Content-Type': 'application/json; charset=utf-8'
                }
              }).then(function (response) {
                return response.data;
              });
            case 5:
              return _context.abrupt("return", _context.sent);
            case 6:
            case "end":
              return _context.stop();
          }
        }, _callee);
      }));
      function getResults(_x) {
        return _getResults.apply(this, arguments);
      }
      return getResults;
    }()
  }]);
  return MarketingSearchAPI;
}();
var _default = exports.default = MarketingSearchAPI;