"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _regenerator = _interopRequireDefault(require("@babel/runtime/regenerator"));
var _asyncToGenerator2 = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));
var _classCallCheck2 = _interopRequireDefault(require("@babel/runtime/helpers/classCallCheck"));
var _createClass2 = _interopRequireDefault(require("@babel/runtime/helpers/createClass"));
var _axios = _interopRequireDefault(require("axios"));
var _Locale = require("../Locale");
/**
 * Copyright IBM Corp. 2020, 2022
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

/**
 * @constant {string | string} Host for the API calls
 * @private
 */
var _host = process && process.env.SEARCH_TYPEAHEAD_API || 'https://www-api.ibm.com';
/**
 * @constant {string | string} API version
 * @private
 */
var _version = process && process.env.SEARCH_TYPEAHEAD_VERSION || 'v1';
/**
 * SearchTypeahead endpoint
 *
 * @type {string}
 * @private
 */
var _endpoint = "".concat(_host, "/search/typeahead/").concat(_version);
/**
 * SearchTypeahead API class with methods of fetching search results for
 * ibm.com
 */
var SearchTypeaheadAPI = /*#__PURE__*/function () {
  function SearchTypeaheadAPI() {
    (0, _classCallCheck2.default)(this, SearchTypeaheadAPI);
  }
  (0, _createClass2.default)(SearchTypeaheadAPI, null, [{
    key: "getResults",
    value:
    /**
     * Gets search results
     *
     * @param {string} query Query string to pass to the service
     * @returns {Promise<any>} Response data from ibm search
     * @example
     * import { SearchTypeaheadAPI } from '@carbon/ibmdotcom-services';
     *
     * async function getResults(query) {
     *   const response = await SearchTypeaheadAPI.getResults(query);
     *   return response;
     * }
     */
    function () {
      var _getResults = (0, _asyncToGenerator2.default)( /*#__PURE__*/_regenerator.default.mark(function _callee(query) {
        var appid,
          lang,
          urlQuery,
          url,
          _args = arguments;
        return _regenerator.default.wrap(function _callee$(_context) {
          while (1) switch (_context.prev = _context.next) {
            case 0:
              appid = _args.length > 1 && _args[1] !== undefined ? _args[1] : '';
              _context.next = 3;
              return _Locale.LocaleAPI.getLang();
            case 3:
              lang = _context.sent;
              urlQuery = ["lang=".concat(lang.lc).concat(lang.cc ? "&cc=".concat(lang.cc) : ''), "query=".concat(encodeURIComponent(query)), "".concat(appid ? "appid=".concat(appid) : '')].filter(function (item) {
                return item;
              }).join('&');
              url = "".concat(_endpoint, "?").concat(urlQuery);
              _context.next = 8;
              return _axios.default.get(url, {
                headers: {
                  'Content-Type': 'application/json; charset=utf-8'
                }
              }).then(function (response) {
                return response.data.response;
              });
            case 8:
              return _context.abrupt("return", _context.sent);
            case 9:
            case "end":
              return _context.stop();
          }
        }, _callee);
      }));
      function getResults(_x) {
        return _getResults.apply(this, arguments);
      }
      return getResults;
    }()
  }]);
  return SearchTypeaheadAPI;
}();
var _default = exports.default = SearchTypeaheadAPI;