"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _jsCookie = _interopRequireDefault(require("js-cookie"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }
function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, _toPropertyKey(descriptor.key), descriptor); } }
function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); } /**
 * Copyright IBM Corp. 2020, 2022
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
/**
 * Name of cookie needed to grab cc and lc
 *
 * @type {string}
 * @private
 */
var _cookieName = 'ipcInfo';

/**
 * Utility to set and get the ipcInfo cookie needed to determine country and language code
 */
var ipcinfoCookie = /*#__PURE__*/function () {
  function ipcinfoCookie() {
    _classCallCheck(this, ipcinfoCookie);
  }
  _createClass(ipcinfoCookie, null, [{
    key: "get",
    value:
    /**
     * retreive the ipcInfo cookie that contains the cc and lc
     * decodes and converts to object
     *
     * @example
     * import { ipcinfoCookie } from '@carbon/ibmdotcom-utilities';
     *
     * const info = ipcinfoCookie.get();
     */
    function get() {
      var cookiesDecode = _jsCookie.default.withConverter({
        read: function read(value) {
          return decodeURIComponent(value);
        }
      });
      var ipcinfo = cookiesDecode.get(_cookieName);
      if (ipcinfo) {
        var cc;
        var lc;
        var info = ipcinfo.split(';');
        info.map(function (code) {
          var itemParts = code.split('=');
          if (itemParts[0] === 'cc') cc = itemParts[1];
          if (itemParts[0] === 'lc') lc = itemParts[1];
        });
        return {
          cc: cc,
          lc: lc
        };
      }
    }

    /**
     * set the ipcInfo cookie with expiration of a year
     * takes care of converting to string and encoding
     *
     * @param {object} params params object
     * @param {string} params.cc country code
     * @param {string} params.lc language code
     * @example
     * import { ipcinfoCookie } from '@carbon/ibmdotcom-utilities';
     *
     * const locale = {cc: 'us', lc: 'en'}
     * ipcinfoCookie.set(locale);
     */
  }, {
    key: "set",
    value: function set(_ref) {
      var cc = _ref.cc,
        lc = _ref.lc;
      var info = "cc=".concat(cc, ";lc=").concat(lc);
      var cookiesEncode = _jsCookie.default.withConverter({
        write: function write(value) {
          return encodeURIComponent(value);
        }
      });
      cookiesEncode.set(_cookieName, info, {
        expires: 365,
        domain: '.ibm.com'
      });
    }
  }]);
  return ipcinfoCookie;
}();
var _default = exports.default = ipcinfoCookie;